#### Quantify and Modeling Text

We are going to process the text with 🤗 transformer

Please search a model here, to quantify and model the text input, we both use the 🤗 pretrained name, model's name should be the same with tokenizer's name. Eg. "bert-base-uncased"

Please consider the language and task, when choosing pretrained model

eg. use "bert-base-chinese" for Chinese language, use "raynardj/roberta-pubmed" for English medical text